trade_shiny: A Shiny Interface to the trade Package
Description
Launch a shiny interface to simulate the effects of tariffs
Usage
trade_shiny()
Arguments
Details
trade_shiny launches a shiny interface for the trade package. The shiny interface provides users with the
ability to calibrate model parameters and simulate tariff effects using many of the supply and demand models
included in the trade package.